@@ -21,37 +21,35 @@ import java.io.StringWriter;
 
 /**
  * Convenience class to handle throwable stacktraces
- *
- * <p>Created on 18/06/2003</p>
+ * <p>
+ * Created on 18/06/2003
+ * </p>
  *
  * @author <a href="mailto:bert@tuaworks.co.nz">Bert van Brakel</a>
- * @version $Revision$
+ * @version $Id: $Id
+ * @since 3.4.0
  */
-public class Tracer
-{
+public class Tracer {
 
     /**
      * Constructor
-     *
-     *
      */
-    private Tracer()
-    {
+    private Tracer() {
         super();
     }
 
     /**
      * Return the throwable stack trace as a string
-     * */
-    public static String traceToString( Throwable t )
-    {
-        if ( t == null )
-        {
+     *
+     * @param t a {@link java.lang.Throwable} object.
+     * @return a {@link java.lang.String} object.
+     */
+    public static String traceToString(Throwable t) {
+        if (t == null) {
             return null;
         }
         StringWriter sw = new StringWriter();
-        t.printStackTrace( new PrintWriter( sw ) );
+        t.printStackTrace(new PrintWriter(sw));
         return sw.toString();
     }
-
 }
