@@ -16,30 +16,36 @@ package org.codehaus.plexus.util.dag;
  * limitations under the License.
  */
 
-import junit.framework.TestCase;
-
 import java.util.ArrayList;
 import java.util.List;
 
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 /**
+ * <p>CycleDetectedExceptionTest class.</p>
+ *
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
- * @version $Id$
+ * @version $Id: $Id
+ * @since 3.4.0
  */
-public class CycleDetectedExceptionTest
-        extends TestCase
-{
-    public void testException()
-    {
+public class CycleDetectedExceptionTest {
+    /**
+     * <p>testException.</p>
+     */
+    @Test
+    public void testException() {
         final List<String> cycle = new ArrayList<String>();
 
-        cycle.add( "a" );
+        cycle.add("a");
 
-        cycle.add( "b" );
+        cycle.add("b");
 
-        cycle.add( "a" );
+        cycle.add("a");
 
-        final CycleDetectedException e = new CycleDetectedException( "Cycle detected", cycle );
+        final CycleDetectedException e = new CycleDetectedException("Cycle detected", cycle);
 
-        assertEquals( "Cycle detected a --> b --> a", e.getMessage() );
+        assertEquals("Cycle detected a --> b --> a", e.getMessage());
     }
 }
